@@ -14,7 +14,7 @@ from iframes import IFramer
 
 MAJOR = "0"
 MINOR = "0"
-MAINTAINENCE = "49"
+MAINTAINENCE = "55"
 
 
 def version():
@@ -46,9 +46,14 @@ class SuperKabuki(Stream):
     Super Kabuki - SCTE-35 Packet injection
 
     """
-
+    _PACKET_SIZE = 188
+    _SYNC_BYTE = 0x47
+    # tids
+    PMT_TID = b"\x02"
+    SCTE35_TID = b"\xFC"
+    _SDT_TID = b"\x42"
     CUEI_DESCRIPTOR = b"\x05\x04CUEI"
-
+    
     def __init__(self, tsdata=None):
         self.infile = None
         self.outfile = "superkabuki-out.ts"
@@ -97,7 +102,7 @@ class SuperKabuki(Stream):
         parser.add_argument(
             "-p",
             "--scte35_pid",
-            #default=1000,
+            #default=0x86,
             #type=int,
             help="""Pid for SCTE-35 packets, can be hex or integer. (default 0x86)""",
         )
@@ -168,7 +173,7 @@ class SuperKabuki(Stream):
             nbin.add_int(7, 3)  # reserved  0b111
             nbin.add_int(self.scte35_pid, 13)
             nbin.add_int(15, 4)  # reserved 0b1111
-            es_info_length = 0
+            es_info_length = 3
             nbin.add_int(es_info_length, 12)
             scte35_stream = nbin.bites
             print2("Stream Added:")
@@ -188,7 +193,9 @@ class SuperKabuki(Stream):
         if isinstance(self.outfile, str):
             self.outfile = open(self.outfile, "wb")
         with self.outfile as out_file:
-            for pkt in self._find_start():
+            if not self._find_start():
+                return
+            for pkt in self.iter_pkts():
                 pid = self._parse_info(pkt)
                 if self._pusi_flag(pkt):
                     self._parse_pts(pkt, pid)
@@ -247,7 +254,6 @@ class SuperKabuki(Stream):
                             insert_pts = pts
                         if insert_pts >= pts:
                             if [insert_pts, cue] not in self.sidecar:
-                                print2((insert_pts, cue))
                                 self.sidecar.append([insert_pts, cue])
                                 self.sidecar = deque(
                                     sorted(self.sidecar, key=itemgetter(0))
@@ -291,7 +297,6 @@ class SuperKabuki(Stream):
         padding = b"\xff" * pad_size
         nbin.add_bites(padding)
         self._bump_cc()
-        # print2(nbin.bites)
         return nbin.bites
 
     def _program_stream_map(self, pkt, pid):
@@ -333,7 +338,7 @@ class SuperKabuki(Stream):
         """
         parse program maps for streams
         """
-        pay = self._chk_partial(pay, pid, self._PMT_TID)
+        pay = self._chk_partial(pay, pid, self.PMT_TID)
         if not pay:
             return False
         seclen = self._parse_length(pay[1], pay[2])
@@ -365,7 +370,9 @@ class SuperKabuki(Stream):
         si_len = n_seclen - 9
         si_len -= proginfolen
         streams = self._parse_program_streams(si_len, pay, idx, program_number)
-        n_streams = self._pmt_scte35_stream() + streams
+       # print2(streams)
+        n_streams = streams+self._pmt_scte35_stream()
+       # print2(n_streams)
         self._regen_pmt(pcr_pid, n_info_bites, n_streams)
         return True
 
